Index: apps/app_confbridge.c
===================================================================
--- apps/app_confbridge.c	(revision 399145)
+++ apps/app_confbridge.c	(working copy)
@@ -1339,6 +1339,9 @@
 		return -1;
 	}
 
+	/* To make sure playback_chan has the same language of that profile */
+	ast_channel_language_set(conference->playback_chan, conference->b_profile.language); 
+
 	ast_debug(1, "Created announcer channel '%s' to conference bridge '%s'\n",
 		ast_channel_name(conference->playback_chan), conference->name);
 	return 0;
Index: apps/confbridge/conf_config_parser.c
===================================================================
--- apps/confbridge/conf_config_parser.c	(revision 399145)
+++ apps/confbridge/conf_config_parser.c	(working copy)
@@ -257,6 +257,15 @@
 						will be used.
 					</para></description>
 				</configOption>
+				<configOption name="language" default="en">
+					<synopsis>The language used for internal playback</synopsis>
+					<description><para>
+						By default, the internal playback within a conference is using english.
+						Which means all prompts played within the conference (to all users) will be english.
+						This is the case for the prompts when a user joins and leaves. By changing the
+						language of a bridge, this will change the language of all prompts played to all users.
+					</para></description>
+				</configOption>
 				<configOption name="mixing_interval">
 					<synopsis>Sets the internal mixing interval in milliseconds for the bridge</synopsis>
 					<description><para>
@@ -1417,6 +1426,7 @@
 
 	ast_cli(a->fd,"--------------------------------------------\n");
 	ast_cli(a->fd,"Name:                 %s\n", b_profile.name);
+	ast_cli(a->fd,"Language:             %s\n", b_profile.language);
 
 	if (b_profile.internal_sample_rate) {
 		snprintf(tmp, sizeof(tmp), "%d", b_profile.internal_sample_rate);
@@ -1934,6 +1944,7 @@
 	aco_option_register(&cfg_info, "record_file_append", ACO_EXACT, bridge_types, "yes", OPT_BOOLFLAG_T, 1, FLDSET(struct bridge_profile, flags), BRIDGE_OPT_RECORD_FILE_APPEND);
 	aco_option_register(&cfg_info, "max_members", ACO_EXACT, bridge_types, "0", OPT_UINT_T, 0, FLDSET(struct bridge_profile, max_members));
 	aco_option_register(&cfg_info, "record_file", ACO_EXACT, bridge_types, NULL, OPT_CHAR_ARRAY_T, 0, CHARFLDSET(struct bridge_profile, rec_file));
+	aco_option_register(&cfg_info, "language", ACO_EXACT, bridge_types, "en", OPT_CHAR_ARRAY_T, 0, CHARFLDSET(struct bridge_profile, language));
 	aco_option_register_custom(&cfg_info, "^sound_", ACO_REGEX, bridge_types, NULL, sound_option_handler, 0);
 	/* This option should only be used with the CONFBRIDGE dialplan function */
 	aco_option_register_custom(&cfg_info, "template", ACO_EXACT, bridge_types, NULL, bridge_template_handler, 0);
Index: apps/confbridge/include/confbridge.h
===================================================================
--- apps/confbridge/include/confbridge.h	(revision 399145)
+++ apps/confbridge/include/confbridge.h	(working copy)
@@ -192,6 +192,7 @@
 
 struct bridge_profile {
 	char name[64];
+	char language[MAX_LANGUAGE];					  /*!< Language used for playback_chan */
 	char rec_file[PATH_MAX];
 	unsigned int flags;
 	unsigned int max_members;          /*!< The maximum number of participants allowed in the conference */
Index: configs/confbridge.conf.sample
===================================================================
--- configs/confbridge.conf.sample	(revision 399145)
+++ configs/confbridge.conf.sample	(working copy)
@@ -197,6 +197,9 @@
                            ;               is the single source of video distribution among all participants. If
                            ;               that user leaves, the marked user to join after them becomes the source.
 
+;language=en               ; This option is used to stream in that specific language for all the prompts
+                           ; stream to all users within the conference. Default is en (English).
+
 ; All sounds in the conference are customizable using the bridge profile options below.
 ; Simply state the option followed by the filename or full path of the filename after
 ; the option.  Example: sound_had_joined=conf-hasjoin  This will play the conf-hasjoin
